#
# spec file for package canna
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           canna
Version:        3.7p3
Release:        bp155.4.47
Summary:        Kana and Kanji Conversion System
# http://canna.sourceforge.jp/
License:        BSD-3-Clause
Group:          System/I18n/Japanese
URL:            http://www.nec.co.jp/japanese/product/computer/soft/canna/
# select mirror from
# http://sourceforge.jp/projects/canna/downloads/9565/Canna37p3.tar.bz2/
Source:         Canna37p3.tar.bz2
Source1:        candoc.tar.bz2
Source2:        rccanna
Source3:        hosts.canna
Source4:        jisx6002.kpdef
Source5:        canna.service
Source6:        canna-tmpfiles.conf
Source99:       baselibs.conf
Patch0:         unoff1.patch
Patch5:         security.patch
Patch7:         Canna.conf.patch
Patch9:         canuum.suse.patch
# multibyte patch needed for Nicolatter,
# see http://www2.airnet.ne.jp/pak04955/dl-linux.htm
# Patch can also be found in the nicolatter package
Patch11:        Canna36p3-q1.diff
Patch12:        default-dictionaries.patch
Patch14:        security-okir.patch
Patch15:        add-kpdef.patch
Patch17:        sort.patch
Patch18:        control-reaches-end-of-void-function.patch
Patch19:        noconfwrapper.patch
Patch20:        canna-noredefine_fgets.patch
Patch21:        canna-include.patch
Patch22:        fix-uninit.patch
Patch23:        canna-strip.patch
Patch24:        bug-262623-internet-usage-broken-by-security-patch.patch
Patch25:        Canna37p3-destbufferoverflow.patch
Patch26:        canna-fiximplicit.patch
Patch27:        safe-sockdir.patch
BuildRequires:  automake
BuildRequires:  gcc
BuildRequires:  imake
BuildRequires:  ncurses-devel
BuildRequires:  pwdutils
BuildRequires:  termcap
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
Requires(pre):  /bin/rm
Recommends:     cannadic
%if 0%{?suse_version} < 1230
Requires(pre):  %insserv_prereq
%else
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%endif
# Summary(ja):  Canna - かな漢字変換システム
# %description -n canna -l ja
# UNIX 上で共通に使える日本語入力システムとして Wnn が存在しました。
# 『かんな』は UNIX 上の日本語入力として Wnn 以外にもう一つの選択肢を
# 与えることができればと思いフリーソフトウェアとして誰でも利用できるよ
# うにしました。
#
#
# 『かんな』は Wnn と同様、アプリケーションプログラムとかな漢字変換辞
# 書をアクセスするかな漢字変換サーバが別のプロセスとして分離されたクラ
# イアント・サーバ型の動作をします。このことを含め『かんな』の特長とし
# て以下があります。
#
#
# (1) クライアント・サーバ方式のかな漢字変換
# (2) 逐次自動変換のサポート
# (3) 統一的なユーザインタフェースの提供
# (4) 広範囲なカスタマイズのサポート
# (5) lisp 言語ベースのカスタマイズ記述
# (6) 単語登録時の最適な品詞づけ
# (7) 統一的なユーザインタフェースを簡単に提供するためのライブラリ
# (8) 辞書をメンテナンスするためのコマンド群
# (9) カスタマイズを簡単に行うためのカスタマイズツールの提供
# (10) Nemacs(Mule)、kinput2、uum のサポート

%description
Canna converts Kana to Kanji based on a client/server model. An
application program communicates with a Kana to Kanji conversion server
to achieve Japanese input. Canna can be used in Emacs, X Window System
environments, and on TTYs. Canna provides more than ten tools to
maintain Kana to Kanji conversion dictionaries.

%package -n canna-libs
Summary:        Canna Shared Libraries
Group:          System/Libraries
Provides:       canna:%{_prefix}/lib/libcanna.so.1.1
#Summary(ja): Canna ユーザインタフェースレベルのライブラリ
# %description -n canna-libs -l ja
# Canna ユーザインタフェースレベルのライブラリ

%description -n canna-libs
Canna Shared Libraries

%package -n canna-devel
Summary:        Canna Development Headers and Libraries
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}-libs = %{version}
Provides:       cannadev = %{version}-%{release}
Obsoletes:      cannadev < %{version}-%{release}
#Summary(ja): Canna ユーザインタフェースレベルのライブラリ
# %description -n canna-devel -l ja
# Canna ユーザインタフェースレベルのライブラリ

%description -n canna-devel
Canna development headers and libraries.

%prep
%setup -q -n Canna37p3 -a 1
%patch0 -p1 -b .unoff1
%patch5 -p1 -b .security
%patch7 -p1 -b .Canna.conf
%patch9 -p1 -b .canuum.suse
%patch11 -p1 -b .Canna36p3-q1.diff
%patch12 -p1 -b .default-dictionaries
%patch14 -p1 -b .security-okir
%patch15 -p1 -b .add-kpdef
%patch17 -p1 -b .sortcall
%patch18 -p1 -b .control-reaches-end-of-void-function
%patch19 -p1 -b .noconfwrapper
%patch20  -b .noredefine
perl -pi -e 's#%{_prefix}/lib/termcap#%{_libdir}/termcap#' canuum/Imakefile
perl -pi -e 's#lib64#%{_lib}#' Canna.conf
cp ${RPM_SOURCE_DIR}/jisx6002.kpdef dic/phono/
%patch21 -p1
%patch22
%patch23
%patch24 -p1
%patch25
%patch26 -p1
%patch27 -p1

%build
xmkmf
# parallel make does not work in some stages
make -j1 Makefile
make -j1 CDEBUGFLAGS="%{optflags} -fPIC -fno-strict-aliasing" CXXDEBUGFLAGS="%{optflags} -fPIC -fno-strict-aliasing" canna
pushd canuum
    cp %{_datadir}/automake*/config.{guess,sub} .
    export CDEBUGFLAGS="%{optflags} -fno-strict-aliasing"
    export CXXDEBUGFLAGS="%{optflags} -fno-strict-aliasing"
    xmkmf -a
    make %{?_smp_mflags} CDEBUGFLAGS="%{optflags} -fno-strict-aliasing" CXXDEBUGFLAGS="%{optflags} -fno-strict-aliasing"
popd

%install
# create home directory for user 'wnn':
mkdir -p %{buildroot}%{_localstatedir}/lib/wnn
# add user 'wnn' (also used for Canna, not only for wnn)
%{_sbindir}/useradd -r -o -g bin -u 66 -s /bin/false -c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn 2> /dev/null || :
make install DESTDIR=%{?buildroot} RPM_BUILD=TRUE
make install.man MANSUFFIX=1 LIBMANSUFFIX=3 DESTDIR=%{?buildroot}
# Make links for utility programs
# (excluded from Make process via RPM_BUILD=TRUE)
#.....................................................................
(cd %{?buildroot}%{_prefix}/bin; \
for i in cpdic lsdic mkdic mvdic rmdic syncdic addwords delwords
do
	ln -sf catdic $i
done; \
ln -sf ../bin/catdic ../sbin/cannakill)
#.....................................................................
pushd canuum
    make install DESTDIR=%{?buildroot}
    make install.man MANSUFFIX=1 LIBMANSUFFIX=3 DESTDIR=%{?buildroot}
    chmod 755 %{buildroot}%{_bindir}/canuum
popd
%if 0%{?suse_version} < 1230
mkdir -p %{buildroot}%{_initddir}
mkdir -p %{buildroot}%{_sbindir}
%else
mkdir -p %{buildroot}/%{_unitdir}
mkdir -p %{buildroot}%{_prefix}/lib/tmpfiles.d
%endif
mkdir -p %{buildroot}%{_sysconfdir}/hosts.canna
mkdir -p %{buildroot}%{_localstatedir}/lib/canna/log
%if 0%{?suse_version} < 1230
install -m 755 %{_sourcedir}/rccanna %{buildroot}%{_initddir}/canna
ln -s ../..%{_initddir}/canna %{buildroot}%{_sbindir}/rccanna
%else
install -m 644 %{_sourcedir}/canna.service %{buildroot}/%{_unitdir}/canna.service
install -m 644 %{_sourcedir}/canna-tmpfiles.conf %{buildroot}%{_prefix}/lib/tmpfiles.d/canna-tmpfiles.conf
%endif
install -m 644 %{_sourcedir}/hosts.canna %{?buildroot}%{_sysconfdir}/hosts.canna
# Remove all cannakill manpages because we've disabled it in
# the server.
rm -f `find %{buildroot}%{_mandir} -name 'cannakill*'`
rm -f %{buildroot}%{_sbindir}/cannakill
find %{buildroot} -type f -name "*.a" -delete -print

%pre -n canna
%{_sbindir}/useradd -r -o -g bin -u 66 -s /bin/false -c "Wnn System Account" -d %{_localstatedir}/lib/wnn wnn 2> /dev/null || :
%if 0%{?suse_version} >= 1230
%service_add_post canna.service
%endif

%post -n canna
%if 0%{?suse_version} < 1230
%{fillup_and_insserv -y canna}
%else
%service_add_post canna.service
%tmpfiles_create %{_tmpfilesdir}/canna-tempfiles.conf
%endif

%preun -n canna
%if 0%{?suse_version} < 1230
%stop_on_removal canna
%else
%service_del_preun canna.service
%endif

%postun -n canna
%if 0%{?suse_version} < 1230
%restart_on_update canna
%insserv_cleanup
%else
%service_del_postun canna.service
%endif
if [ "$1" = "0" ]; then
  rm -rf /run/canna
fi

%post -n canna-libs -p /sbin/ldconfig
%postun -n canna-libs -p /sbin/ldconfig

%files
%doc CHANGES.jp README{,.jp} WHATIS{,.jp} candoc
%dir %attr(-,wnn,root) %{_localstatedir}/log/canna
%dir %attr(-,wnn,root) %{_localstatedir}/lib/canna/log
%dir %attr(-,wnn,root) %{_localstatedir}/lib/wnn
%{_sysconfdir}/hosts.canna
%if 0%{?suse_version} < 1230
%{_initddir}/canna
%{_sbindir}/rccanna
%else
%{_unitdir}/canna.service
%{_prefix}/lib/tmpfiles.d/canna-tmpfiles.conf
%endif
# don't package cannakill, it is disabled by okir's security patch anyway
# /usr/sbin/cannakill
# more secure permission for cannaserver
# (setuid and setgid bits was set per default).
%attr(755,root,root) %{_sbindir}/cannaserver
%{_bindir}/*
%config %{_localstatedir}/lib/canna/default.canna
#%config /var/lib/canna/engine.cf
%dir %{_localstatedir}/lib/canna/
%dir %attr(755,wnn,root) %{_localstatedir}/lib/canna/dic/
%attr(-,wnn,root) %{_localstatedir}/lib/canna/dic/*cbp
%dir %attr(755,wnn,root) %{_localstatedir}/lib/canna/dic/canna/
%attr(-,wnn,root) %{_localstatedir}/lib/canna/dic/canna/*
%{_localstatedir}/lib/canna/sample/
%dir %{_mandir}/ja/
%dir %{_mandir}/ja/man1/
%{_mandir}/ja/man1/*
%{_mandir}/man1/*

%files -n canna-libs
%{_libdir}/lib*.so.*

%files -n canna-devel
%{_libdir}/lib*.so
%dir %{_includedir}/canna
%{_includedir}/canna/*.h
%dir %{_mandir}/ja/
%dir %{_mandir}/ja/man3/
%{_mandir}/ja/man3/*
%{_mandir}/man3/*

%changelog
* Fri May  6 2022 Matthias Gerstner <matthias.gerstner@suse.com>
- add safe-sockdir.patch: move UNIX socket dir from /tmp to /run to avoid
  local attackers being able to place bogus directories in its stead. Use
  systemd-tmpfiles for cleaning old sockets (bsc#1199280).
* Wed Aug 25 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Modified:
  * canna.service
* Sat Nov  9 2019 Marguerite Su <i@marguerite.su>
- ran spec-cleaner
- do not install static archive into -devel package
- put devel file lib*.so in -devel package
* Mon Feb 19 2018 crrodriguez@opensuse.org
- BuildRequires imake not xorg-x11-devel
* Tue Mar  7 2017 i@marguerite.su
- Fix factory build, remove unrecognized RPM_SOURCE_DIR
* Thu Feb 19 2015 ftake@geeko.jp
- Fix the insufficient fix for boo#910933
  + fix /tmp/.iroha_unix is not removed at service start
* Fri Jan  2 2015 ftake@geeko.jp
- Fix boo#910933 Canna cannot start
  + roll back the fix for bnc#878691
  + use wnn user instead of canna
  + fix the command line options in canna.service
  + use /bin/rm instead of cannakill in canna.service
* Mon Nov 10 2014 i@marguerite.su
- add baselibs.conf to Source99
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in postun script
* Mon May 26 2014 dvaleev@suse.com
- add canna user for systemd-tmpfiles (bnc#878691)
* Wed May 14 2014 meissner@suse.com
- add %%service_add_pre to %%pre section
* Sat Oct 26 2013 p.drouand@gmail.com
- Improve systemd support for openSUSE >= 12.3
- Remove sysconfig and %%fillup_prereq PreReq; package doesn't contain
  any sysconfig file, these macros are useless
- Don't provide INSTALL and INSTALL.jp in documentation; it describes
  how do build from source have nothing to do in package
* Wed Jul 17 2013 bkbin005@rinku.zaq.ne.jp
- Remove obsoleted authors section .
  Please see also
  http://lists.opensuse.org/opensuse-ja/2013-07/msg00099.html
* Sun Jul  7 2013 ftake@geeko.jp
- remove locale(ja) and not installed by default because most users
  do not use this package anymore
- fix source URL
* Sat Jun  2 2012 i@marguerite.su
- fix sles builds.
* Tue May 29 2012 jengelh@inai.de
- Enable parallel build
- Adjust directory name to source config.guess/sub from
  to be a /little/ more future proof.
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
* Thu Mar 15 2012 dvaleev@suse.com
- copy config.guess, as the stock one is too old and not able to
  guess ppc64
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Tue Dec  7 2010 coolo@novell.com
- prereq init script network
* Wed Dec  9 2009 meissner@suse.de
- added some unistd.h includes
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Aug 17 2009 tiwai@suse.de
- changed from requires to recommends for cannadic in order to
  cut the dependency loop
* Mon Dec  1 2008 ro@suse.de
- added baselibs.conf for canna-libs (required by uim)
* Wed Oct  8 2008 crrodriguez@suse.de
- fix buffer overflow
* Sun Aug 24 2008 ro@suse.de
- initscript: add $remote_fs to should start (binary below /usr)
  copy Required-Start list to Required-Stop to fix build
- remove outdated options from fillup_and_insserv call
* Mon Apr 16 2007 mfabian@suse.de
- Bugzilla #262623: "canna internet usage broken by suse security
  jail patch": fix with patch supplied by IBM.
* Fri Mar 30 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Thu Jan 25 2007 sndirsch@suse.de
- move from /usr/X11R6 to /usr
* Tue Feb 28 2006 mfabian@suse.de
- add "Provides: locale(ja)".
* Thu Feb  2 2006 tiwai@suse.de
- fixed the broken system path via non-root build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 schwab@suse.de
- Don't strip binaries.
* Wed Dec 21 2005 ro@suse.de
- remove not packaged cannakill symlink
* Sun Oct 30 2005 dmueller@suse.de
- fix build
- fix build with non-root
* Wed Sep 21 2005 yxu@suse.de
- add prototypes for functions
* Mon Jun 13 2005 ro@suse.de
- do not redefine fgets
* Wed Jun  8 2005 uli@suse.de
- build with -fPIC, static libs are used in loadable modules by
  some packages
* Mon Sep 20 2004 mfabian@suse.de
- Bugzilla #45561: move .so files to canna-libs package. uim needs
  the .so files but uim should not need to have canna-devel
  installed to work.
* Tue Jul 27 2004 mfabian@suse.de
- update to 37p3.
* Mon May 24 2004 ro@suse.de
- skip confwrapper which breaks with new XVENDORNAME
* Mon Apr  5 2004 mfabian@suse.de
- Bugzilla #37733: fix insecure use of temporary files in
  /etc/init.d/canna.
* Tue Mar  9 2004 mfabian@suse.de
- update to 37p1.
* Tue Oct 14 2003 meissner@suse.de
- suse_update_config for new config.guess.
* Tue Oct  7 2003 ro@suse.de
- fix sort calling syntax
* Thu Sep 18 2003 mfabian@suse.de
- Bugzilla #31220: fix permissions and ownerships.
* Sat Sep 13 2003 mfabian@suse.de
- Bugzilla #29396: apply patch for x86_64.
  Many thanks to Mitsuru Chinen <mchinen@yamato.ibm.com>.
* Mon Sep  1 2003 mfabian@suse.de
- update to 3.6p3.
- remove patch which added the canuum sources (included now).
- Build canuum against ncurses instead of against termcap,
  adapt SuSE patch to suppress the "permission denied" messages
  when leaving canuum.
- add latest patch for Nicolatter: Canna36p3-q1.diff
- remove most of Canna35b2-unoff1.patch (mostly included in 3.6p3,
  I'll check the remaining ones in detail later).
- remove Canna35b2-unoff2.patch (already included in 3.6p3).
- remove Canna35b2-hack1.patch (already included in 3.6p3).
- remove Canna35b2.patch (already included in 3.6p3).
- remove Canna35b2.intptr.dif (included upstream).
- remove Canna35b2.dif (obsolete).
- adapt Olaf Kirchs security patch.
* Tue Aug 19 2003 mfabian@suse.de
- Use new stop_on_removal/restart_on_upate macros.
- add %%run_ldconfig to %%post and %%postun of canna-libs.
* Mon Jun 16 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Wed Oct 23 2002 mfabian@suse.de
- map '|' (= Shift+Yen on the jp106 keyboard) to
  U+30FC "KATAKANA-HIRAGANA PROLONGED SOUND MARK" in the
  JIS X 6002 keymap (Requested by Shunya).
* Wed Oct 23 2002 mfabian@suse.de
- add keyboard map for JIS X 6002 keyboard.
* Wed Aug 21 2002 mfabian@suse.de
- add security patch by Olaf Kirch okir at suse.de which makes
  cannaserver run in a chroot jail and fixes some other security
  problems
- link canuum statically against libtermcap to remove the
  dependency on libtermcap.rpm
- use $RPM_OPT_FLAGS
- .spec file cleanup
* Wed Aug 14 2002 mfabian@suse.de
- fix typo in .spec file which led to omission of the .la files
  in canna-devel
* Sun Aug 11 2002 mfabian@suse.de
- move shared libraries into new sub-package "canna-libs".
  This is to make dynamic linking of canna clients possible without
  making them require the whole 3.6 MB canna package.
- replace network route named -> $network $named
  in Required-Start of /etc/init.d/canna
* Thu Aug  1 2002 mfabian@suse.de
- add /bin/rm %%insserv_prereq %%fillup_prereq to Prereq:
* Sat Jul 27 2002 adrian@suse.de
- add %%run_ldconfig
* Wed Jul 24 2002 mfabian@suse.de
- Don't parse rc.config in init script
- add home-dir to base package
- change usage of useradd in pre script to comply with
  the package howto
* Mon Apr 22 2002 mfabian@suse.de
- fix %%{_libdir} for x86_64
* Sat Jan 26 2002 mfabian@suse.de
- use %%{_libdir}
* Thu Jan 17 2002 ro@suse.de
- added imakefile.dif to force early include generation
* Thu Jan 10 2002 egmont@suselinux.hu
- changed /sbin/init.d to /etc/init.d in init script comment
* Fri Dec  7 2001 mfabian@suse.de
- get rid of START_CANNA variable in /etc/rc.config:
  use new macros fill_up_and_insserv and insserv_cleanup and
  remove testing for START_CANNA from init script.
* Mon Sep 17 2001 mfabian@suse.de
- integrate canuum into the main package again. Splitting it
  into a sub-package is too late for SuSE 7.3.
* Sun Sep 16 2001 mfabian@suse.de
- move canuum into an additional sub-package. Only canuum needs
  libtermcap, by moving it into a sub-package, the main canna
  packages doesn't require libtermcap anymore.
* Sat Sep  8 2001 mfabian@suse.de
- added entry "yubin7" to the default dictionary lists
* Fri Sep  7 2001 mfabian@suse.de
- mount more dictionaries by default, especially mount
  the supplemental cannadic dictionaries by default
- add Requires: cannadic.
* Tue May 22 2001 mfabian@suse.de
- add a /etc/hosts.canna file to limit the access to the
  cannaserver to the local host by default.
* Thu May  3 2001 mfabian@suse.de
- make init script comply with latest LSB spec
* Thu Mar  8 2001 mfabian@suse.de
- improve init script (wait for server to remove socket, using
  Werner's new "usleep")
- fix %%postun, "sbin/init.d" -> "etc/init.d"
* Wed Mar  7 2001 mfabian@suse.de
- add xf86 to "# neededforbuild"
* Fri Mar  2 2001 mfabian@suse.de
- add multibyte patch needed for Nicolatter.
* Mon Nov 27 2000 mfabian@suse.de
- removed socket before starting the Canna server.
  sometimes these socket remains after killing the Canna server
  which prevents a restart.
* Mon Nov 27 2000 mfabian@suse.de
- added "route named" to "Required-Start:"
- moved init script to /etc/init.d
* Fri Nov 24 2000 mfabian@suse.de
- fixed bug in new init script
* Thu Nov 23 2000 mfabian@suse.de
- change to new init script mechanism:
  rewrote rccanna and use insserv to handle links to init script
* Thu Nov 16 2000 mfabian@suse.de
- added missing newline at end of file "rc.config.canna"
* Sun Nov 12 2000 ro@suse.de
- never redeclare/redefine bcopy/bzero
* Sat Oct 28 2000 mfabian@suse.de
- avoided "permission denied" messages when leaving canuum
  (on exit, canuum called chown("/dev/ptyp1", 0, 0),
  chmod("/dev/ptyp1", 0666), chown("/dev/ttyp1", 0, 0)
  and chmod("/dev/ttyp1", 0666). This only worked as long as
  canuum was suid root and failed now because bk@suse.de
  removed the suid bits. But these chown and chmod don't
  seem to make sense on linux anyway, therefore I just
  removed them).
- changed Japanese locale from ja_JP.ujis to ja_JP to stop
  (this stops canuum from complaining about wrong locale during
  startup)
- add "useradd wnn" to the pre-install script, to make it build
  and install on systems where there is no user wnn yet
  (e.g. SuSE 7.0, 6.4)
- used bzip2 for sources instead of gzip.
- removed some garbage from old patches
* Fri Oct 27 2000 bk@suse.de
- fixed startproc call(security)
- changed canna uid from bin to wnn
- removed suid bits from binaries
- fixed uninstall scripts
* Fri Sep 22 2000 schwab@suse.de
- Fix integer/pointer clashes.
* Thu Aug 10 2000 mfabian@suse.de
- moved Japanese manpages from subdirectories "ja_JP.ujis" to
  subdirectories "ja".
* Mon Jul 17 2000 mfabian@suse.de
- security patch, fixes buffer overrun problem in function
  SetDicHome( client, cxnum ) in file Canna35b2/server/misc.c
* Tue Jul 11 2000 mfabian@suse.de
- fixed links to noexisting manpages.
  Some manpages were still links to pages in section 3x:
  mfabian@gregory:/usr/X11R6/man/man3$ zcat XKanjiControl.3.gz
  .so man3/uilib.3x
  and these didn't exist, because we did put them in section 3.
